import java.awt.*;
import java.awt.geom.*;
import javax.swing.*;

import app.*;
import io.*;
import visual.VisualizationView;
import visual.dynamic.described.*;
import visual.statik.sampled.*;

/**
 * An example of "sprite animation" that uses: tweening, interaction 
 * between sprites, and interaction with the user.
 *
 * @author  Prof. David Bernstein, James Madison University
 * @version 1.0
 */
public class   BalloonApp
       extends AbstractMultimediaApp
{
    private static final int SIZE = 4; // Of each color
    

    /**
     * The entry point of the application
     */
    public void init()
    {
       Balloon                         gold, purple;
       Cupola                          cupola;
       Image                           cursor;       
       ImageFactory                    imageFactory;       
       int                             stageHeight, stageWidth;       
       JPanel                          contentPane;       
       ResourceFinder                  finder;       
       Stage                           stage;
       Toolkit                         toolkit;
       TransformableContent            content, goldContent, purpleContent;
       ContentFactory                  tcFactory;
       VisualizationView               stageView;
       
       finder       = ResourceFinder.createInstance(this);       
       tcFactory = new ContentFactory(finder);

       // The Stage
       stageWidth   = 640;
       stageHeight  = 480;       
       stage        = new Stage(50);
       stageView    = stage.getView();       
       toolkit      = stageView.getToolkit(); 
       imageFactory = new ImageFactory(finder);       
       cursor       = imageFactory.createBufferedImage("blankcursor.png",4);
       content = tcFactory.createContent("roof.png", 3, false);
       stage.add(content);
       //stage.setBackground(new Color(116, 126, 156)); 
       stageView.setBounds(0, 0, stageWidth, stageHeight);
       stageView.setCursor(toolkit.createCustomCursor(cursor, new Point(0,0), 
                                                      "Blank"));

       // The cupola
       content = tcFactory.createContent("cupola.png", 
                        4, false);
       cupola  = new Cupola(content, stageWidth, stageHeight);
       stage.add(cupola);
       stage.addMouseMotionListener(cupola);
        

       // The balloons
       for (int i=0; i<SIZE; i++)
       {
          goldContent   = tcFactory.createContent("balloon-gold.png", 4, 
                                                  false);
          purpleContent = tcFactory.createContent("balloon-purple.png", 4, 
                                                  false);

          gold    = new Balloon(goldContent, stageWidth, stageHeight);
          gold.addAntagonist(cupola);       
          stage.add(gold);

          purple    = new Balloon(purpleContent, stageWidth, stageHeight);
          purple.addAntagonist(cupola);       
          stage.add(purple);
       }
       

       // The content pane
       contentPane = (JPanel)rootPaneContainer.getContentPane();
       contentPane.add(stageView);

       stage.start();
    }
}
