import java.awt.*;
import javax.swing.*;

import app.*;

/**
 * An example that illustrates the rendering of glyphs/fonts
 * (using various different classes)
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 */
public class   GlyphApp
       extends AbstractMultimediaApp
{
    /**
     * <p>
     * The entry point
     * </p>
     *
     * <p>
     * Argument 0 controls the operation of this driver by determining
     * the type of GlyphCanvas to use.  Possibilities include:
     * </p>
     * 
     * <ul>
     *    GlyphCanvas <br/>
     *    GlyphMetricsCanvas <br/>
     *    CenteredGlyphCanvas <br/>
     *    SpiralGlyphCanvas <br/>
     *    AttributedStringCanvas <br/>
     * </ul>
     */
    public void init()
    {
       GlyphCanvas                    canvas;
       JPanel                         contentPane;
       String                         arg;

       arg = rootPaneContainer.getParameter("0");
       if (arg == null) arg = "GlyphCanvas";
       
       if (arg.startsWith("AttributedStringCanvas"))
          canvas = new AttributedStringCanvas();
       else if (arg.startsWith("CenteredGlyphCanvas"))
          canvas = new CenteredGlyphCanvas();
       else if (arg.startsWith("GlyphMetricsCanvas"))
          canvas = new GlyphMetricsCanvas();
       else if (arg.startsWith("SpiralGlyphCanvas"))
          canvas = new SpiralGlyphCanvas();
       else
          canvas = new GlyphCanvas();

       canvas.setBounds(0,0,400,400);
       
       contentPane = (JPanel)rootPaneContainer.getContentPane();
       contentPane.add(canvas);

       arg = rootPaneContainer.getParameter("1");
       if (arg == null) arg = "Glyphs";    
       
       canvas.setText(arg);
       canvas.repaint();
    }
}
