import java.util.*;
import java.awt.event.*;
import javax.sound.midi.*;
import javax.swing.*;

import app.*;
import auditory.described.*;
import io.*;

/**
 * A simple MultimediaApp that uses a Metronome
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 */
public class      OrchestraApp
       extends    AbstractMultimediaApp
       implements ActionListener
{
    private JButton         start;       
    private Orchestra       orchestra;       

    private static final String       START = "Start";


    /**
     * Called to indicate that this MultimediaApp has been loaded
     */
    public void init()
    {
       JLabel                    label;       
       JPanel                    contentPane;       
       ResourceFinder            finder;       
       Score                     score;
       ScoreFactory              factory;
       String                    song;
       
       song    =  rootPaneContainer.getParameter("0");
       if (song == null) song = "OdeToJoy.txt";
       
       finder  = ResourceFinder.createInstance(this);

       factory = new ScoreFactory(finder);
       
       label       = new JLabel(song, SwingConstants.CENTER);
       label.setBounds(0,0,600,100);       

       start = new JButton(START);
       start.setBounds(50,300,100,50);
       start.addActionListener(this);

       try
       {
          score = factory.createScore("/"+song);
          orchestra = new Orchestra(score);       
       }
       catch (Exception e)
       {
          start.setEnabled(false);          
       }
       
       contentPane = (JPanel)rootPaneContainer.getContentPane();   
       contentPane.add(label);    
       contentPane.add(start);
       contentPane.setLayout(null);
    }

    /**
     * Handle actionPerformed messages
     * (required by ActionListener)
     *
     * @param event  The ActionEvent that generated the message
     */
    public void actionPerformed(ActionEvent event)
    {
       String   actionCommand;
       
       actionCommand = event.getActionCommand();
       if      (actionCommand.equals(START))
       {
          orchestra.start();
          start.setEnabled(false);
       }
    }
}
