import java.awt.*;
import javax.swing.*;

import app.*;
import visual.VisualizationView;
import io.ResourceFinder;
import visual.dynamic.sampled.Screen;
import visual.statik.SimpleContent;
import visual.statik.sampled.ContentFactory;

/**
 * An example that illustrates sampled dynamic visual content
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 */
public class   ScreenApp
       extends AbstractMultimediaApp
{
    /**
     * The entry-point of the application
     */
    public void init()
    {
       ContentFactory                        factory;       
       JPanel                                contentPane;
       MovingRectangle                       mr;       
       ResourceFinder                        finder;       
       Screen                                screen;
       SimpleContent[]                       frames;
       String                                arg;       
       String[]                              names;       
       VisualizationView                     component;
        
       screen = new Screen();
       screen.setRepeating(true);
       
       component = screen.getView();       


       names = null;       
       arg = rootPaneContainer.getParameter("0");
       if (arg == null) arg = "solidclock";

       finder = ResourceFinder.createInstance(this);
       
       if (arg.equalsIgnoreCase("solidclock"))
       {
          component.setBounds(0,0,200,200);       
          names = finder.loadResourceNames("solidclock.txt");
          factory = new ContentFactory(finder);          
          frames = factory.createContents(names, 4);
       }
       else if (arg.equalsIgnoreCase("scribble"))
       {
          component.setBounds(0,0,320,240);       
          names = finder.loadResourceNames("scribble.txt");
          factory = new ContentFactory(finder);          
          frames = factory.createContents(names, 4);
       }
       else
       {
          component.setBounds(0,0,200,200);       
          mr     = new MovingRectangle();          
          frames = mr.getFrames();          
       }

       for (int i=0; i<frames.length; i++)
       {
          screen.add(frames[i]);          
       }

       contentPane = (JPanel)rootPaneContainer.getContentPane();
       contentPane.add(component);
       screen.start();       
    }
}
