import java.awt.*;
import java.awt.geom.*;
import javax.swing.*;

import app.*;
import io.ResourceFinder;
import visual.VisualizationView;
import visual.dynamic.sampled.Fade;
import visual.dynamic.sampled.Dissolve;
import visual.dynamic.sampled.Screen;
import visual.dynamic.sampled.TransformableContentSuperimposition;
import visual.statik.TransformableContent;

/**
 * An example that illustrates the use of the
 * TransformableContentSuperimposition class.
 *
 * It includes transitions as well to show that the two
 * can be used together.
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 */

public class   SuperimpositionApp
       extends AbstractMultimediaApp
{
    /**
     * The entry-point
     */
    public void init()
    {
       Dissolve                              dissolve;
       Fade                                  fadeIn, fadeOut;
       JPanel                                contentPane;       
       ResourceFinder                        finder;       
       TransformableContent                  logo;       
       TransformableContent[]                frames;       
       TransformableContentSuperimposition   si;
       Screen                                screen;     
       String                                arg;       
       String[]                              names;       
       VisualizationView                     component;       

       visual.statik.sampled.ContentFactory  factory;

       screen = new Screen(4);
       screen.setRepeating(true);
       component = screen.getView();       
       component.setBackground(Color.WHITE);
       component.setBounds(0,0,200,200);       

       contentPane = (JPanel)rootPaneContainer.getContentPane();
       contentPane.add(component);

       // Setup the animation
       frames = null;       
       finder = ResourceFinder.createInstance(this);
       names = finder.loadResourceNames("solidclock.txt");
       factory = new visual.statik.sampled.ContentFactory(finder);
       frames = factory.createContents(names, 4);

       for (int i=0; i<frames.length; i++)
       {
          screen.add(frames[i]);
       }
       
       fadeIn  = new Fade(Fade.FADE_IN,   0, 6);
       fadeOut = new Fade(Fade.FADE_OUT, 30, 6);
       
       dissolve = new Dissolve(20, 4);
       
       screen.addTransition(fadeIn);

       screen.addTransition(dissolve);

       screen.addTransition(fadeOut);

       // Setup the Superimposition
       logo = null;       
       arg  = rootPaneContainer.getParameter("0");
       if (arg == null)
       {
          logo = factory.createContent("multimedia.png", 4);
       }
       else
       {
          if (arg.equalsIgnoreCase("buzzy"))
          {
             logo = new BuzzyStanding();
          }
          else 
          {
             logo = factory.createContent("multimedia-transparent.png", 4);
          }
       }

       si = new TransformableContentSuperimposition(
                                    logo, 
                                    5, 10, SwingConstants.SOUTH_EAST);
       
       screen.addSuperimposition(si);
       screen.start();       
    }
}
