import java.awt.*;
import javax.swing.*;

import app.*;
import io.ResourceFinder;
import visual.VisualizationView;
import visual.dynamic.sampled.Fade;
import visual.dynamic.sampled.Dissolve;
import visual.dynamic.sampled.RectangleWipe;
import visual.dynamic.sampled.Screen;
import visual.statik.SimpleContent;
import visual.statik.sampled.ContentFactory;

/**
 * An application that illustrates the use of transitions
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 */
public class   TransitionApp
       extends AbstractMultimediaApp
{
    /**
     * The entry-point
     */
    public void init()
    {
       ContentFactory                        factory;
       Dissolve                              dissolve;
       Fade                                  fadeIn, fadeOut;
       JPanel                                contentPane;       
       RectangleWipe                         wipe;
       ResourceFinder                        finder;       
       Screen                                screen;
       SimpleContent[]                       frames;       
       String                                arg;       
       String[]                              names;       
       VisualizationView                     component;

       screen = new Screen(24);
       screen.setRepeating(true);
       component = screen.getView();       
       component.setBounds(0,0,320,240);       

       contentPane = (JPanel)rootPaneContainer.getContentPane();
       contentPane.add(component);
       
       finder = ResourceFinder.createInstance(this);
       factory = new ContentFactory(finder);

       frames = null;       
       names = finder.loadResourceNames("scribble.txt");
       frames = factory.createContents(names, 4);

       fadeIn  = new Fade(Fade.FADE_IN,  0, 24);
       screen.addTransition(fadeIn);
          
       wipe = new RectangleWipe(72, 24);
       screen.addTransition(wipe);             

       fadeOut = new Fade(Fade.FADE_OUT, 126, 24);
       screen.addTransition(fadeOut);

       for (int i=0; i<frames.length; i++)
       {
          screen.add(frames[i]);
       }
       
       screen.start();       
    }
}
