import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import javax.swing.*;

import app.*;
import io.*;
import visual.VisualizationView;
import visual.dynamic.described.*;
import visual.statik.sampled.*;

/**
 * An example of described dynamic visual content that uses
 * multiple Content objects for each Sprite
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 */
public class   SwimmingFishTankApp
       extends AbstractMultimediaApp
{
    /**
     * The entry point
     */
    public void init()
    {
       BufferedImage                image;
       BufferedImage[]              images;
       Content                      content;
       Content[]                    contents;       
       ContentFactory               factory;       
       ImageFactory                 imageFactory;
       int                          height, width;       
       JPanel                       contentPane;       
       ResourceFinder               finder;       
       Stage                        stage;
       SwimmingFish                 fish, shark;
       VisualizationView            stageView;       

       width  = 640;
       height = 480;       

       finder       = ResourceFinder.createInstance(this);       
       factory      = new ContentFactory(finder);       
       imageFactory = new ImageFactory(finder);

       // The Stage
       stage = new Stage(50);
       stage.setBackground(Color.blue);
       content = factory.createContent("ocean.png", 3, false);
       stage.add(content);
       stageView = stage.getView();
       stageView.setBounds(0,0,width,height);       

       // The Shark
       images = imageFactory.createBufferedImages("swimmingshark.png", 
                                                  3, 4);
       contents = new Content[3];          
       for (int j=0; j<contents.length; j++)
       {
          contents[j] = factory.createContent(images[j], false);
       }
       shark = new SwimmingFish(contents, width, height, 8.);
       stage.add(shark);

       // The school of Fish
       // (Use the same BufferedImage object for all Fish)
       images  = imageFactory.createBufferedImages("swimmingfish.png", 
                                                   3, 4);
       for (int i=0; i<10; i++)
       {
          contents = new Content[3];          
          for (int j=0; j<contents.length; j++)
          {
             contents[j] = factory.createContent(images[j], false);
          }
          
          fish = new SwimmingFish(contents, width, height, 3.);
          fish.addAntagonist(shark);       
          stage.add(fish);
       }
       
       // The content pane
       contentPane = (JPanel)rootPaneContainer.getContentPane();
       contentPane.add(stageView);

       stage.start();
    }
}
