import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import java.io.*;
import javax.swing.*;

import app.*;
import event.*;
import io.*;
import visual.*;
import visual.dynamic.described.*;
import visual.statik.sampled.*;

/**
 * An example that illustrates the use of a "display wall" (i.e.,
 * networked computers that are used to create one large virtual
 * display).  This particular example assumes that the two displays
 * are side-by-side.
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 */
public class   WallApp
       extends AbstractMultimediaApp
{
    /**
     * The entry point
     */
    public void init()
    {
       BigBus                       bus;
       BufferedImage                image;       
       Content                      content;
       ContentFactory               factory;       
       ImageFactory                 imageFactory;
       int                          delay, height, port, width;       
       JPanel                       contentPane;       
       Metronome                    metronome;
       ResourceFinder               finder;       
       Stage                        stage;
       String                       param;
       VisualizationRenderer        renderer;       
       VisualizationView            stageView;       
       UDPMetronomeBroadcaster      broadcaster;

       delay  = 50;       
       width  = 640;
       height = 480;       
       port   = 22801;       

       finder       = ResourceFinder.createInstance(this);       
       factory      = new ContentFactory(finder);       
       imageFactory = new ImageFactory(finder);

       param        = rootPaneContainer.getParameter("0");       
       if (param == null) param = "server";       

       // The Stage
       if (param.equals("left"))
       {
          try
          {
             stage = new Stage(delay, new UDPDrivenMetronome(port));
             stageView = stage.getView();       
             renderer  = new PartialVisualizationRenderer(stageView.getRenderer(),
                                                          0.0, 0.0);          
             stageView.setRenderer(renderer);
             stageView.setBounds(0, 0, width/2, height);    
          }
          catch (IOException ioe)
          {
             System.err.println("Using Local Metronome");             
             stage = new Stage(delay);             
             stageView = stage.getView();       
          }
       }
       else if (param.equals("right"))
       {
          try
          {
             stage = new Stage(delay, new UDPDrivenMetronome(port));
          
             stageView = stage.getView();    
             renderer = new PartialVisualizationRenderer(
                            new PlainVisualizationRenderer(), width/2, 0);
             
             stageView.setRenderer(renderer);
             stageView.setBounds(0, 0, width/2, height);    
          }
          catch (IOException ioe)
          {
             System.err.println("Using Local Metronome");             
             stage = new Stage(delay);             
             stageView = stage.getView();       
          }
       }
       else // "server"
       {
          stage = new Stage(delay);
          stageView = stage.getView();    
          renderer = new ScaledVisualizationRenderer(stageView.getRenderer(),
                                                     width, height);
          stageView.setRenderer(renderer);          
          stageView.setBounds(0, 0, width/2, height);
          stageView.setSize(width/2, height/2);          
          try
          {
             broadcaster = new UDPMetronomeBroadcaster(22801);
             metronome   = stage.getMetronome();             
             metronome.addListener(broadcaster);
          }
          catch (IOException ioe)
          {
             System.err.println("Unable To Start Server");
          }
       }
       stage.setBackground(Color.blue);
       content = factory.createContent("street.png", 3, false);
       stage.add(content);

       // The BigBus
       content = factory.createContent("bigbus.png", 4, false);
       bus = new BigBus(content, width, height, stage);
       stage.add(bus);

       // The streetligts in the foreground
       image   = imageFactory.createBufferedImage("streetlight.png", 4);
       content = factory.createContent(image, false);
       content.setLocation(60, 270);       
       stage.add(content);
       content = factory.createContent(image, false);
       content.setLocation(370, 270);       
       stage.add(content);
       
       // The content pane
       contentPane = (JPanel)rootPaneContainer.getContentPane();
       contentPane.add(stageView);

       stage.start();
    }
}
