//[skeleton0
package visual.dynamic.described;

import java.awt.*;
import java.util.*;

import event.*;
import visual.*;
import visual.statik.sampled.*;

/**
 * A Visualization that contains Sprite objects
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 *
 */
public class Stage extends    Visualization 
                   implements MetronomeListener
{
    private boolean              shouldRestart;
    private int                  timeStep, restartTime, time;
    private Metronome            metronome;

    /**
     * Explicit Value Constructor
     *
     * @param timeStep    Amount of time between ticks (in milliseconds)
     */
    public Stage(int timeStep)
    {  
       this(timeStep, new Metronome(timeStep));
    }

    /**
     * Explicit Value Constructor
     *
     * @param timeStep    Amount of time between ticks (in milliseconds)
     * @param metronome   The Metronome to use
     */
    public Stage(int timeStep, Metronome metronome)
    {       
       super();
       
       this.timeStep     =  timeStep;
       time              = -timeStep;
       shouldRestart     =  false;
       restartTime       = -1;
       this.metronome    = metronome;
       setBackground(Color.WHITE);

       // The first listener is notified last
       metronome.addListener(this);
    }
//]skeleton0

//[sprites0
    /**
     * Add a Sprite to this Stage
     *
     * @param sprite   The Sprite to add
     */
    public void add(Sprite sprite)
    {
       // Make the Sprite a MetronomeListener
       metronome.addListener(sprite);

       // Treat the Sprite as a SimpleContent and
       // add it to the Visualization
       super.add(sprite);       
    }    
//]sprites0

    /**
     * Get the Metronome that this Stage is using
     *
     * @return  The Metronome
     */
    public Metronome getMetronome()
    {
       return metronome;       
    }

//[handleTick
    /**
     * Handle "tick" events (required by MetronomeTickListener)>
     *
     * @param time  The time of the "tick"
     */
    public void handleTick(int time)
    {
       if ((shouldRestart) && (time > restartTime)) 
       {
          metronome.setTime(-timeStep);
       }
       
       repaint();
    }
//]handleTick
//[sprites1

    /**
     * Remove a Sprite from this Stage
     *
     * @param sprite   The Sprite to remove
     */
    public void remove(Sprite sprite)
    {
       metronome.removeListener(sprite);
       super.remove(sprite);       
    }    
//]sprites1

//[metronome
    /**
     * Set the time at which the Stage should restart
     *
     * @param restartTime   In milliseconds (negative to not restart)
     */
    public void setRestartTime(int restartTime)
    {
       if (restartTime < 0)
       {
          this.restartTime = -1;
          shouldRestart = false;
       }
       else
       {
          this.restartTime = restartTime;
          shouldRestart = true;
       }
    }

    /**
     * Start the Stage
     */
    public void start()
    {
       metronome.start();
    }

    /**
     * Stop the Stage
     */
    public void stop()
    {
       metronome.stop();
    }
//]metronome
//[skeleton1
}
//]skeleton1
